======================
 @public and @private
======================

This library provides two very simple decorators that document the
*publicness* of the names in your module.  They keep your module's ``__all__``
in sync so you don't have to.


Author
======

``public`` is Copyright (C) 2016-2021 Barry Warsaw <barry@python.org>

Licensed under the terms of the Apache License Version 2.0.  See the LICENSE
file for details.


Project details
===============

 * Project home: https://gitlab.com/warsaw/public
 * Report bugs at: https://gitlab.com/warsaw/public/issues
 * Code hosting: https://gitlab.com/warsaw/public.git
 * Documentation: https://public.readthedocs.io
 * PyPI: https://pypi.python.org/pypi/atpublic
